==> ShopMadeSimple-0.3.7.zip: ShopMadeSimple/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Shop Made Simple';
$lang['admin_description'] = 'This module forms the base of preparing a shop. It handles the products and their grouping. Images and attributes are available per product';
$lang['message_postinstall'] = 'Be sure to set permissions to use this module.';
$lang['message_postuninstall'] = 'If images have been added, they are not removed during uninstall.';
$lang['message_confirmuninstall'] = 'Really? You\'re sure you want to uninstall this module?';

// Common translations
$lang['installed'] = 'Module version %s installed.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['upgraded'] = 'Module upgraded to version %s.';

$lang['cancel'] = 'Cancel';
$lang['submit'] = 'Submit';
$lang['done'] = 'Done';
$lang['update'] = 'Update';
$lang['continue'] = 'Continue';
$lang['module_example_stylesheet']='Module: Shop Made Simple';
$lang['root'] = 'Root';
$lang['error'] = 'Error!';

// Translations in alphabetic order
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['active'] = 'Active';
$lang['addattribute'] = 'Add Attribute';
$lang['addcategory'] = 'Add Category';
$lang['addimage'] = 'Add Image';
$lang['addtocart'] = 'Add to Cart';
$lang['adjusttypemin'] = '- Min';
$lang['adjusttypeplus'] = '+ Plus';
$lang['adjusttypetimes'] = '* Times';
$lang['adjusttypevalue'] = 'Value';
$lang['baseproductprice'] = '(Product base price: %s)';
$lang['column_attribute_adjustment'] = 'Adjustment';
$lang['column_attribute_description'] = 'Description';
$lang['column_attribute_display'] = 'Calculate with?';
$lang['column_attribute_itemnumber'] = 'Item number';
$lang['column_attribute_maxallowed'] = 'Max';
$lang['column_attribute_minallowed'] = 'Min';
$lang['column_attribute_name'] = 'Name';
$lang['column_attribute_price'] = 'Price';
$lang['column_image_description'] = 'Description';
$lang['column_image_name'] = 'Image file';
$lang['deletecategory'] = 'Delete Category';
$lang['firstpage'] = '<<';
$lang['inventorytype_none'] = 'Not used';
$lang['inventorytype_prod'] = 'Per product';
$lang['inventorytype_attr'] = 'Per attribute';
$lang['label_attribute'] = 'Attribute';
$lang['label_admin_email'] = 'Administrator Email';
$lang['label_admin_name'] = 'Administrator Name';
$lang['label_allowdoubleitem'] = 'Allow double item numbers?';
$lang['label_attribute_active'] = 'Attribute is active?';
$lang['label_attribute_description'] = 'Description';
$lang['label_attribute_displayonly'] = 'Only display the attribute?';
$lang['label_attribute_itemnumber'] = 'Item number';
$lang['label_attribute_maxallowed'] = 'Maximum allowed';
$lang['label_attribute_minallowed'] = 'Minimum allowed';
$lang['label_attribute_name'] = 'Name';
$lang['label_attribute_priceadjusttype'] = 'Price adjust type';
$lang['label_attribute_priceadjustment'] = 'Price adjustment';
$lang['label_attribute_product_name'] = 'Attribute for product';
$lang['label_attributes_product_name'] = 'Attributes for product';
$lang['label_categories'] = 'Categories';
$lang['label_categories_template'] = 'Categories';
$lang['label_category_active'] = 'Category is active?';
$lang['label_category_description'] = 'Description';
$lang['label_category_id'] = 'Category';
$lang['label_category_image'] = 'Image';
$lang['label_category_name'] = 'Name';
$lang['label_category_parent'] = 'Parent Category';
$lang['label_category_position'] = 'List Order';
$lang['label_catlist_template'] = 'Category & Products';
$lang['label_current_category'] = 'Current Category';
$lang['label_decimalpositionsprice'] = 'Decimals to use in prices';
$lang['label_decimalseparatorprice'] = 'Decimal point character';
$lang['label_decimalpositionsweight'] = 'Decimals to use in weights';
$lang['label_decimalseparatorweight'] = 'Decimal point character';
$lang['label_default_currency'] = 'Default Currency';
$lang['label_default_language'] = 'Default Language';
$lang['label_default_maxattributes'] = 'Default maximum attributes per product';
$lang['label_default_sku'] = 'Default Stock Keeping Unit';
$lang['label_default_symbol'] = 'Default Currency Symbol';
$lang['label_displayquickselector'] = 'Display the quick selector';
$lang['label_image_description'] = 'Description';
$lang['label_image_name'] = 'Name';
$lang['label_image_product_name'] = 'Images for product';
$lang['label_imagepath_category'] = 'Path to category images';
$lang['label_imagepath_product'] = 'Path to product images';
$lang['label_inventorysettings'] = 'Inventory Settings';
$lang['label_inventorytype'] = 'Inventory to track';
$lang['label_item_capital_only'] = 'Itemnumber capitals only';
$lang['label_numberformatting'] = 'Number Formatting';
$lang['label_onstock'] = 'On stock';
$lang['label_prices_incl_vat'] = 'Prices are inclusive VAT';
$lang['label_proddetail_template'] = 'Product detail';
$lang['label_prodfeat_template'] = 'Featured products';
$lang['label_product'] = 'Product';
$lang['label_product_active'] = 'Product is active?';
$lang['label_product_category'] = 'Products for';
$lang['label_product_category_id'] = 'Category';
$lang['label_product_description'] = 'Description';
$lang['label_product_featured'] = 'Feature this product';
$lang['label_product_id'] = 'ID';
$lang['label_product_image'] = 'Image';
$lang['label_product_itemnumber'] = 'Item number';
$lang['label_product_maxattributes'] = 'Maximum allowed attributes';
$lang['label_product_name'] = 'Name';
$lang['label_product_netweight'] = 'Nett Weight';
$lang['label_product_position'] = 'List Order';
$lang['label_product_price'] = 'Price';
$lang['label_product_sku'] = 'Stock Keeping Unit (SKU)';
$lang['label_product_vatcode'] = 'VAT';
$lang['label_productpagelimit'] = 'Number of products per page';
$lang['label_quantity_onstock'] = 'Quantity on stock';
$lang['label_salesinventtiming'] = 'When should inventory be decreased';
$lang['label_shop_name'] = 'Shop Name';
$lang['label_shop_online'] = 'Shop Online';
$lang['label_shop_phone'] = 'Shop Emergency Phone';
$lang['label_sku_description'] = 'Description';
$lang['label_sku_name'] = 'Name';
$lang['label_tab_attributes'] = 'Attributes';
$lang['label_tab_categories'] = 'Categories and Products';
$lang['label_tab_images'] = 'Images';
$lang['label_tab_options'] = 'Options';
$lang['label_tab_product'] = 'Product Details';
$lang['label_tab_product_categories'] = 'Categories';
$lang['label_tab_skus'] = 'SKU\'s';
$lang['label_tab_template'] = 'Templates';
$lang['label_tab_templates'] = 'Templates';
$lang['label_thousandseparatorprice'] = 'Thousands separator';
$lang['label_thousandseparatorweight'] = 'Thousands separator';
$lang['label_tnheight_product'] = 'Product thumbnail height';
$lang['label_tnwidth_product'] = 'Width';
$lang['label_weight_unit_measure'] = 'Product weight in';
$lang['lastpage'] = '>>';
$lang['message_areyousureattribute'] = 'Are you sure you want to delete attribute: %s?';
$lang['message_areyousurecategory'] = 'Are you sure you want to delete category: %s?';
$lang['message_areyousureimage'] = 'Are you sure you want to delete image: %s?';
$lang['message_areyousureprodcat'] = 'Are you sure you want to disconnect this product: %s from category %s?';
$lang['message_areyousureproduct'] = 'Are you sure you want to delete product: %s?';
$lang['message_areyousuresku'] = 'Are you sure you want to delete SKU: %s?';
$lang['message_attributeadded'] = 'Attribute: %s has been added';
$lang['message_attributedeleted'] = 'Attribute: %s has been deleted';
$lang['message_doubleitemnumberfound'] = 'Double item number found, see product \'%s\'';
$lang['message_imageadded'] = 'Image: %s has been added';
$lang['message_imagedeleted'] = 'Image: %s has been deleted';
$lang['message_noattributenamegiven'] = 'No attribute name given, while this is mandatory';
$lang['message_noattributetosave'] = 'No attribute information to save. No attribute added';
$lang['message_noimagetoupload'] = 'No image to upload. No image added';
$lang['nextpage'] = '>';
$lang['no_attributes_available'] = 'No attributes available';
$lang['no_folder_available'] = 'Folder %s to hold images not available (security problem?)';
$lang['no_images_available'] = 'No images available';
$lang['nocatfound'] = 'No categories found';
$lang['noprodfound'] = 'No products found';
$lang['noprodfoundforsearch'] = 'No products found with given search criteria';
$lang['piece'] = 'Piece';
$lang['optionsupdated'] = 'Options have been updated';
$lang['prevpage'] = '<';
$lang['pricesincurexvat'] = 'All prices in %s, excluding TAX/VAT';
$lang['pricesincurinvat'] = 'All prices in %s, including TAX/VAT';
$lang['print'] = 'Print this page';
$lang['print_page'] = 'Print';
$lang['productsoldout'] = 'Sold out';
$lang['productsreindexed'] = 'Products have been reindexed for the Search module';
$lang['productthumbnailsrebuild'] = 'Thumbnails of products have been rebuild';
$lang['prompt_of'] = 'of';
$lang['prompt_page'] = 'Page';
$lang['properties_updated'] = 'Properties have been updated';
$lang['rebuildproductthumbnails'] = 'Rebuild';
$lang['salesinventtiming_cnf'] = 'Status changes to confirmed';
$lang['salesinventtiming_int'] = 'Status changes to confirmed';
$lang['salesinventtiming_inv'] = 'Invoice is send';
$lang['salesinventtiming_pay'] = 'Status changes to paid';
$lang['salesinventtiming_shp'] = 'Status changes to shipped';
$lang['searchitem'] = 'Search';
$lang['searchreindex'] = 'Reindex for Search';
$lang['ShopMS_MaintainCategory'] = 'Shop Made Simple: Maintain Categories';
$lang['ShopMS_MaintainProducts'] = 'Shop Made Simple: Maintain Products';
$lang['ShopMS_MaintainSKUs'] = 'Shop Made Simple: Maintain Stock Keeping Units';
$lang['ShopMS_UseShopMadeSimple'] = 'Shop Made Simple: All permissions';
$lang['skudeleted'] = 'Stock keeping unit %s deleted';
$lang['skuinuse'] = 'Can\'t delete, stock keeping unit is, at least, in use in product: %s';
$lang['templatesupdated'] = 'Templates have been updated';
$lang['text_active'] = 'Set Active';
$lang['text_add'] = 'Add';
$lang['text_calculation'] = 'Use calculation';
$lang['text_category'] = 'Category';
$lang['text_delete'] = 'Delete';
$lang['text_edit'] = 'Edit';
$lang['text_inactive'] = 'Set Inactive';
$lang['text_nocalculation'] = 'Just show the attributes name';
$lang['text_product'] = 'Product';
$lang['text_sku'] = 'Stock Keeping Unit';
$lang['textmore'] = ' ...';
$lang['textproductcount'] = 'Total %s product(s) found:';
$lang['title_hide'] = 'Hide';
$lang['title_show'] = 'Show';
$lang['title_quick_selector'] = 'Quick selector';
$lang['tooltip_maxattributes'] = 'This field allows you to have the visitor to select up to given number of attributes. 
Blank or zero means no limit.';
$lang['tooltip_quantity_onstock'] = 'Enter here the quantity of stock that you have.';
$lang['unknown_display'] = 'Parameter \'display\' not defined in action.default.php';
$lang['variouscategories'] = 'One or more categories';

// Admin
$lang['helpcatname'] = 'Name of category. Must exactly match. If left blank, the products from the root category will be shown. 
This parameter is only used if the parameter display contains productlist (see example).';
$lang['helpdisplay'] = 'Specifies the type of display you want to show. There are currently two available:<ul>
	<li>categorylist (default) - shows a list of the categories and the number of products within category (one level only!);</li>
	<li>catlist - shows list of categories with number of products. Use this if multiple levels of categories are used;</li>
	<li>featured - shows a list of the products that are marked as featured;</li>
	<li>productlist - show products from a named category.</li>
</ul>';
$lang['helppagenumber'] = 'Enter the number of the page that the products should be shown. \'pagenumber=2\' will show all products as of page 2. 
The visitor will be able to use the previous page and the next (if any). If the pagenumber is not passed, page 1 will be shown.';
$lang['helpparentcategory'] = 'Internal number of category. This will show a list of all the categories using the provided number as parent. 
The internal number can be found on the left side of each category in the admin page of this module.';
$lang['helpprodpagelimit'] = 'The number of products that are to be shown on one page. This overrides the value as entered in the options.';
$lang['helpstart'] = 'The starting value for the page of products. If you want to show all products starting at the fourth, use \'start=4\'.';

$lang['help'] = '
<h3>How Do I Use It</h3>
<p>
A visitor of the website will see a list of categories. You will be able to show a list of the categories by placing a smarty tag in a page or template using &#123;cms_module module=ShopMadeSimple}.<br> 
Using the parameter connected to a category, you are able to show products linked to that category.<br>
An example is: {cms_module module=ShopMadeSimple display=\'productlist\' catname=\'Gardentools\'}. This will show all products that are connected to the
category name \'Gardentools\'. Using the display=\'productlist\' without a category name will show the products in the root.<br> 
Another example is: {cms_module module=ShopMadeSimple display=\'categorylist\'}. This will show the various categories. If one is selected, all the connected products are shown.<br>
If you don\'t want to see an image for a category on the front end, place \'no_image.jpg\' in the field \'Image\'.<br><br>
When the Search module is installed, all the words as entered in the product name and product description will be part of the search index.<br>
If the Search module is installed after this module, one can use the button Reindex for Search from the options tab in the back end.<br />
When you use inventory tracking, the quantity sold will be subtracted from the quantity on stock at the moment that payment has been 
received.

<h3>Support</h3>
<p>When you have upgraded this module, please read the About information for installation/upgrade issues.</p>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report see the <a href="http://dev.cmsmadesimple.org/projects/sms">projects homepage</a>;</li>
<li>Commercial support is available via Duketown\'s module homepage at <a href="http://www.duketown.eu">Duketown</a>;</li>
<li>Buy the <a href="http://www.duketown.eu/shop">CMS Made Simple book</a> from Duketown, which describes in detail how to use this module;</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2008-2011.<br>
Author: Duketown
<p>Now that you are using this free module, why not share a tiny bit of your earned money via a donation via Duketown! Thanks in advance.
<form target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="24BEPDT3DVNMJ">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
</p>
';
?>

==> ShopMadeSimple-0.3.9.zip: ShopMadeSimple/lang/en_US.php <==
<?php
$lang['friendlyname'] = 'Shop Made Simple';
$lang['admin_description'] = 'This module forms the base of preparing a shop. It handles the products and their grouping. Images and attributes are available per product';
$lang['message_postinstall'] = 'Module has been installed, be sure to set permissions to use this module.';
$lang['message_postuninstall'] = 'If images have been added, they are not removed during uninstall.';
$lang['message_confirmuninstall'] = 'Really? You\'re sure you want to uninstall this module?';

// Common translations
$lang['installed'] = 'Module version %s installed.';
$lang['uninstalled'] = 'Module Uninstalled.';
$lang['upgraded'] = 'Module upgraded to version %s.';

$lang['cancel'] = 'Cancel';
$lang['submit'] = 'Submit';
$lang['done'] = 'Done';
$lang['update'] = 'Update';
$lang['continue'] = 'Continue';
$lang['module_example_stylesheet']='Module: Shop Made Simple';
$lang['root'] = 'Root';
$lang['error'] = 'Error!';

// Translations in alphabetic order
$lang['accessdenied'] = 'Access Denied. Please check your permissions.';
$lang['active'] = 'Active';
$lang['addattribute'] = 'Add Attribute';
$lang['addcategory'] = 'Add Category';
$lang['addimage'] = 'Add Image';
$lang['addtocart'] = 'Add to Cart';
$lang['adjusttypemin'] = '- Min';
$lang['adjusttypeplus'] = '+ Plus';
$lang['adjusttypetimes'] = '* Times';
$lang['adjusttypevalue'] = 'Value';
$lang['baseproductprice'] = '(Product base price: %s)';
$lang['column_attribute_adjustment'] = 'Adjustment';
$lang['column_attribute_description'] = 'Description';
$lang['column_attribute_display'] = 'Calculate with?';
$lang['column_attribute_itemnumber'] = 'Item number';
$lang['column_attribute_maxallowed'] = 'Max';
$lang['column_attribute_minallowed'] = 'Min';
$lang['column_attribute_name'] = 'Name';
$lang['column_attribute_price'] = 'Price';
$lang['column_image_description'] = 'Description';
$lang['column_image_name'] = 'Image file';
$lang['deletecategory'] = 'Delete Category';
$lang['firstpage'] = '<<';
$lang['inventorytype_none'] = 'Not used';
$lang['inventorytype_prod'] = 'Per product';
$lang['inventorytype_attr'] = 'Per attribute';
$lang['label_attribute'] = 'Attribute';
$lang['label_admin_email'] = 'Administrator Email';
$lang['label_admin_name'] = 'Administrator Name';
$lang['label_allowdoubleitem'] = 'Allow double item numbers?';
$lang['label_attribute_active'] = 'Attribute is active?';
$lang['label_attribute_description'] = 'Description';
$lang['label_attribute_displayonly'] = 'Only display the attribute?';
$lang['label_attribute_itemnumber'] = 'Item number';
$lang['label_attribute_maxallowed'] = 'Maximum allowed';
$lang['label_attribute_minallowed'] = 'Minimum allowed';
$lang['label_attribute_name'] = 'Name';
$lang['label_attribute_priceadjusttype'] = 'Price adjust type';
$lang['label_attribute_priceadjustment'] = 'Price adjustment';
$lang['label_attribute_product_name'] = 'Attribute for product';
$lang['label_attributes_product_name'] = 'Attributes for product';
$lang['label_categories'] = 'Categories';
$lang['label_categories_template'] = 'Categories';
$lang['label_category_active'] = 'Category is active?';
$lang['label_category_description'] = 'Description';
$lang['label_category_id'] = 'Category';
$lang['label_category_image'] = 'Image';
$lang['label_category_name'] = 'Name';
$lang['label_category_parent'] = 'Parent Category';
$lang['label_category_position'] = 'List Order';
$lang['label_catlist_template'] = 'Category & Products';
$lang['label_current_category'] = 'Current Category';
$lang['label_decimalpositionsprice'] = 'Decimals to use in prices';
$lang['label_decimalseparatorprice'] = 'Decimal point character';
$lang['label_decimalpositionsweight'] = 'Decimals to use in weights';
$lang['label_decimalseparatorweight'] = 'Decimal point character';
$lang['label_default_currency'] = 'Default Currency';
$lang['label_default_language'] = 'Default Language';
$lang['label_default_maxattributes'] = 'Default maximum attributes per product';
$lang['label_default_sku'] = 'Default Stock Keeping Unit';
$lang['label_default_symbol'] = 'Default Currency Symbol';
$lang['label_displayquickselector'] = 'Display the quick selector';
$lang['label_image_description'] = 'Description';
$lang['label_image_name'] = 'Name';
$lang['label_image_product_name'] = 'Images for product';
$lang['label_imagepath_category'] = 'Path to category images';
$lang['label_imagepath_product'] = 'Path to product images';
$lang['label_inventorysettings'] = 'Inventory Settings';
$lang['label_inventorytype'] = 'Inventory to track';
$lang['label_item_capital_only'] = 'Itemnumber capitals only';
$lang['label_numberformatting'] = 'Number Formatting';
$lang['label_onstock'] = 'On stock';
$lang['label_prices_incl_vat'] = 'Prices are inclusive VAT';
$lang['label_proddetail_template'] = 'Product detail';
$lang['label_prodfeat_template'] = 'Featured products';
$lang['label_product'] = 'Product';
$lang['label_product_active'] = 'Product is active?';
$lang['label_product_category'] = 'Products for';
$lang['label_product_category_id'] = 'Category';
$lang['label_product_description'] = 'Description';
$lang['label_product_featured'] = 'Feature this product';
$lang['label_product_id'] = 'ID';
$lang['label_product_image'] = 'Image';
$lang['label_product_itemnumber'] = 'Item number';
$lang['label_product_maxattributes'] = 'Maximum allowed attributes';
$lang['label_product_name'] = 'Name';
$lang['label_product_netweight'] = 'Nett Weight';
$lang['label_product_position'] = 'List Order';
$lang['label_product_price'] = 'Price';
$lang['label_product_sku'] = 'Stock Keeping Unit (SKU)';
$lang['label_product_vatcode'] = 'VAT';
$lang['label_productpagelimit'] = 'Number of products per page';
$lang['label_quantity_onstock'] = 'Quantity on stock';
$lang['label_salesinventtiming'] = 'When should inventory be decreased';
$lang['label_shop_name'] = 'Shop Name';
$lang['label_shop_online'] = 'Shop Online';
$lang['label_shop_phone'] = 'Shop Emergency Phone';
$lang['label_sku_description'] = 'Description';
$lang['label_sku_name'] = 'Name';
$lang['label_tab_attributes'] = 'Attributes';
$lang['label_tab_categories'] = 'Categories and Products';
$lang['label_tab_images'] = 'Images';
$lang['label_tab_options'] = 'Options';
$lang['label_tab_product'] = 'Product Details';
$lang['label_tab_product_categories'] = 'Categories';
$lang['label_tab_skus'] = 'SKU\'s';
$lang['label_tab_template'] = 'Templates';
$lang['label_tab_templates'] = 'Templates';
$lang['label_thousandseparatorprice'] = 'Thousands separator';
$lang['label_thousandseparatorweight'] = 'Thousands separator';
$lang['label_tnheight_product'] = 'Product thumbnail height';
$lang['label_tnwidth_product'] = 'Width';
$lang['label_weight_unit_measure'] = 'Product weight in';
$lang['lastpage'] = '>>';
$lang['message_areyousureattribute'] = 'Are you sure you want to delete attribute: %s?';
$lang['message_areyousurecategory'] = 'Are you sure you want to delete category: %s?';
$lang['message_areyousureimage'] = 'Are you sure you want to delete image: %s?';
$lang['message_areyousureprodcat'] = 'Are you sure you want to disconnect this product: %s from category %s?';
$lang['message_areyousureproduct'] = 'Are you sure you want to delete product: %s?';
$lang['message_areyousuresku'] = 'Are you sure you want to delete SKU: %s?';
$lang['message_attributeadded'] = 'Attribute: %s has been added';
$lang['message_attributedeleted'] = 'Attribute: %s has been deleted';
$lang['message_doubleitemnumberfound'] = 'Double item number found, see product \'%s\'';
$lang['message_imageadded'] = 'Image: %s has been added';
$lang['message_imagedeleted'] = 'Image: %s has been deleted';
$lang['message_noattributenamegiven'] = 'No attribute name given, while this is mandatory';
$lang['message_noattributetosave'] = 'No attribute information to save. No attribute added';
$lang['message_noimagetoupload'] = 'No image to upload. No image added';
$lang['nextpage'] = '>';
$lang['no_attributes_available'] = 'No attributes available';
$lang['no_folder_available'] = 'Folder %s to hold images not available (security problem?)';
$lang['no_images_available'] = 'No images available';
$lang['nocatfound'] = 'No categories found';
$lang['noprodfound'] = 'No products found';
$lang['noprodfoundforsearch'] = 'No products found with given search criteria';
$lang['piece'] = 'Piece';
$lang['optionsupdated'] = 'Options have been updated';
$lang['prevpage'] = '<';
$lang['pricesincurexvat'] = 'All prices in %s, excluding TAX/VAT';
$lang['pricesincurinvat'] = 'All prices in %s, including TAX/VAT';
$lang['print'] = 'Print this page';
$lang['print_page'] = 'Print';
$lang['productsoldout'] = 'Sold out';
$lang['productsreindexed'] = 'Products have been reindexed for the Search module';
$lang['productthumbnailsrebuild'] = 'Thumbnails of products have been rebuild';
$lang['prompt_of'] = 'of';
$lang['prompt_page'] = 'Page';
$lang['properties_updated'] = 'Properties have been updated';
$lang['rebuildproductthumbnails'] = 'Rebuild';
$lang['salesinventtiming_cnf'] = 'Status changes to confirmed';
$lang['salesinventtiming_int'] = 'Status changes to confirmed';
$lang['salesinventtiming_inv'] = 'Invoice is send';
$lang['salesinventtiming_pay'] = 'Status changes to paid';
$lang['salesinventtiming_shp'] = 'Status changes to shipped';
$lang['savereturn'] = 'Save and return';
$lang['searchitem'] = 'Search';
$lang['searchreindex'] = 'Reindex for Search';
$lang['ShopMS_MaintainCategory'] = 'Shop Made Simple: Maintain Categories';
$lang['ShopMS_MaintainProducts'] = 'Shop Made Simple: Maintain Products';
$lang['ShopMS_MaintainSKUs'] = 'Shop Made Simple: Maintain Stock Keeping Units';
$lang['ShopMS_UseShopMadeSimple'] = 'Shop Made Simple: All permissions';
$lang['skudeleted'] = 'Stock keeping unit %s deleted';
$lang['skuinuse'] = 'Can\'t delete, stock keeping unit is, at least, in use in product: %s';
$lang['templatesupdated'] = 'Templates have been updated';
$lang['text_active'] = 'Set Active';
$lang['text_add'] = 'Add';
$lang['text_calculation'] = 'Use calculation';
$lang['text_category'] = 'Category';
$lang['text_delete'] = 'Delete';
$lang['text_edit'] = 'Edit';
$lang['text_inactive'] = 'Set Inactive';
$lang['text_nocalculation'] = 'Just show the attributes name';
$lang['text_product'] = 'Product';
$lang['text_sku'] = 'Stock Keeping Unit';
$lang['textmore'] = ' ...';
$lang['textproductcount'] = 'Total %s product(s) found:';
$lang['title_hide'] = 'Hide';
$lang['title_show'] = 'Show';
$lang['title_quick_selector'] = 'Quick selector';
$lang['tooltip_maxattributes'] = 'This field allows you to have the visitor to select up to given number of attributes. 
Blank or zero means no limit.';
$lang['tooltip_quantity_onstock'] = 'Enter here the quantity of stock that you have.';
$lang['unknown_display'] = 'Parameter \'display\' not defined in action.default.php';
$lang['variouscategories'] = 'One or more categories';

// Admin
$lang['helpcategory_id'] = 'The category_id to directly show a list of sub categories.';
$lang['helpcatname'] = 'Name of category. Must exactly match. If left blank, the products from the root category will be shown. 
This parameter is only used if the parameter display contains productlist (see example).';
$lang['helpdetailpage'] = 'The alias of the page to use when detail is requested.';
$lang['helpdisplay'] = 'Specifies the type of display you want to show. There are currently two available:<ul>
	<li>categorylist (default) - shows a list of the categories and the number of products within category (one level only!);</li>
	<li>catlist - shows list of categories with number of products. Use this if multiple levels of categories are used;</li>
	<li>featured - shows a list of the products that are marked as featured;</li>
	<li>productlist - show products from a named category.</li>
</ul>';
$lang['helppagenumber'] = 'Enter the number of the page that the products should be shown. \'pagenumber=2\' will show all products as of page 2. 
The visitor will be able to use the previous page and the next (if any). If the pagenumber is not passed, page 1 will be shown.';
$lang['helpparentcategory'] = 'Internal number of category. This will show a list of all the categories using the provided number as parent. 
The internal number can be found on the left side of each category in the admin page of this module.';
$lang['helpprodpagelimit'] = 'The number of products that are to be shown on one page. This overrides the value as entered in the options.';
$lang['helpstart'] = 'The starting value for the page of products. If you want to show all products starting at the fourth, use \'start=4\'.';

$lang['help'] = '
<h3>How Do I Use It</h3>
<p>
A visitor of the website will see a list of categories. You will be able to show a list of the categories by placing a smarty tag in a page or template using &#123;cms_module module=ShopMadeSimple}.<br> 
Using the parameter connected to a category, you are able to show products linked to that category.<br>
An example is: {cms_module module=ShopMadeSimple display=\'productlist\' catname=\'Gardentools\'}. This will show all products that are connected to the
category name \'Gardentools\'. Using the display=\'productlist\' without a category name will show the products in the root.<br> 
Another example is: {cms_module module=ShopMadeSimple display=\'categorylist\'}. This will show the various categories. If one is selected, all the connected products are shown.<br>
If you don\'t want to see an image for a category on the front end, place \'no_image.jpg\' in the field \'Image\'.<br><br>
When the Search module is installed, all the words as entered in the product name and product description will be part of the search index.<br>
If the Search module is installed after this module, one can use the button Reindex for Search from the options tab in the back end.<br />
When you use inventory tracking, the quantity sold will be subtracted from the quantity on stock at the moment that payment has been 
received.

<h3>Translations</h3>
To keep the module as small as possible, no translations have been included. You can retrieve the 
language that you want to use via <a href="http://svn.cmsmadesimple.org/svn/translatecenter/modules/ShopMadeSimple/lang/ext/">the translation center</a>.<br />
<h3>Support</h3>
<p>When you have upgraded this module, please read the About information for installation/upgrade issues.</p>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module, FAQs, or to file a Bug Report see the <a href="http://dev.cmsmadesimple.org/projects/sms">projects homepage</a>;</li>
<li>Commercial support is available via Duketown\'s module homepage at <a href="http://www.duketown.eu">Duketown</a>;</li>
<li>Buy the <a href="http://www.duketown.eu/shop">CMS Made Simple book</a> from Duketown, which describes in detail how to use this module;</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
</ul>
<p>As per the GPL, this software is provided as-is. Please read the text
of the license for the full disclaimer.</p>

<h3>Copyright and License</h3>
<p>Copyright &copy; 2008-2011.<br>
Author: Duketown
<p>Now that you are using this free module, why not share a tiny bit of your earned money via a donation via Duketown! Thanks in advance.
<form target="_blank" action="https://www.paypal.com/cgi-bin/webscr" method="post">
<input type="hidden" name="cmd" value="_s-xclick">
<input type="hidden" name="hosted_button_id" value="24BEPDT3DVNMJ">
<input type="image" src="https://www.paypalobjects.com/en_US/i/btn/btn_donate_SM.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
<img alt="" border="0" src="https://www.paypalobjects.com/en_US/i/scr/pixel.gif" width="1" height="1">
</form>
</p>
</p>
';
?>
